
# The Ecological-Name-Translator

This project has been ported to the [EcoNameTranslator](https://pypi.org/project/EcoNameTranslator/)- the lightweight but powerful package for full management and translation of ecological names

